# Author: @v1s1t0r999
# Created ON [28-05-2021 @ 15:02]

"""
import LogError

try:
    (SOME CODES WHICH MAY OR MAY NOT GIVE ERRORS)
    (BUT UN-FORTUNATELY)
    (ERROR HAPPENS)
    ("!!! Why Fear When LogError is Here !!!")

except Exception as TheError:
    LogError.handle(file="FileName.log",error=TheError)

"""

import datetime

now = datetime.datetime.now()

class RequiredArgument(Exception):
	pass
class SmtpException(Exception):
	pass

def handle(file,error):
	try:
		if not file:
			raise RequiredArgument("Missing Required Argument: 'file'")
		if not error:
			raise RequiredArgument("Missing Required Argument: 'error'")
		date = now.strftime(f"[%d-%m-%Y @ %H:%M]->")
		F = open(file,"a")
		F.write(f"{str(date)}: {str(error)}\n")
		F.close()
	except Exception as e:
		print(e)




from setuptools import setup
from setuptools import find_packages

version = "1.0.2"

# This call to setup() does all the work
setup(
    name="LogError",
    version=version,
    description="UNKNOWN TRACEBACKS!!!! Deal with them Carefully :-D",
    url="https://github.com/v1s1t0r999/LogError",
    author="v1s1t0r999",
    author_email="aditya.funs.11@gmail.com",
    license="MIT",
    python_requires=">=3.6",
    packages=find_packages(),
    classifiers=[
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.7",
    ],
)